Messaging Content Store HTTP Services API client
=======================

A client library for the Messaging Content Store HTTP Services APIs.

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.

Release Notes
------------------------------
0.1.7 - 2015-07-02 - Fix message content URL path
0.1.4 - 2015-06-11 - Python 3 compat imports
0.1.3 - 2015-05-21 - Initial release
